@@ -30,11 +30,13 @@
 #import <AppKit/AppKit.h>
 
 #include <glib.h>
-#include <clutter/clutter-debug.h>
-#include <clutter/clutter-device-manager.h>
-#include <clutter/clutter-keysyms.h>
-#include <clutter/clutter-private.h>
-#include <clutter/clutter-stage-private.h>
+
+#include "clutter-debug.h"
+#include "clutter-device-manager.h"
+#include "clutter-event-private.h"
+#include "clutter-keysyms.h"
+#include "clutter-private.h"
+#include "clutter-stage-private.h"
 
 #include "clutter-event-loop-osx.h"
 
@@ -220,13 +222,16 @@ static void
 process_scroll_event (ClutterEvent *event,
                       gboolean isVertical)
 {
-  ClutterStageWindow   *impl;
+  ClutterStageWindow *impl;
   ClutterStageOSX *stage_osx;
+  gfloat *scroll_pos;
+
+  impl = _clutter_stage_get_window (event->any.stage);
+  stage_osx = CLUTTER_STAGE_OSX (impl);
   
-  impl        = _clutter_stage_get_window (event->any.stage);
-  stage_osx   = CLUTTER_STAGE_OSX (impl);
-  
-  gfloat *scroll_pos = isVertical ? &(stage_osx->scroll_pos_y) : &(stage_osx->scroll_pos_x);
+  scroll_pos = isVertical
+             ? &(stage_osx->scroll_pos_y)
+             : &(stage_osx->scroll_pos_x);
  
   while (abs (*scroll_pos) >= WHEEL_DELTA) 
     {
