@@ -143,12 +143,11 @@ test_actor_clone_main (int argc, char *argv[])
 
   error = NULL;
 
-  clutter_init_with_args (&argc, &argv,
-                          NULL,
-                          super_oh_entries,
-                          NULL,
-                          &error);
-  if (error)
+  if (clutter_init_with_args (&argc, &argv,
+                              NULL,
+                              super_oh_entries,
+                              NULL,
+                              &error) != CLUTTER_INIT_SUCCESS)
     {
       g_warning ("Unable to initialise Clutter:\n%s",
                  error->message);
