@@ -100,7 +100,8 @@ test_behave_main (int argc, char *argv[])
 	}
     }
   
-  clutter_init (&argc, &argv);
+  if (clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
+    return 1;
 
   stage = clutter_stage_new ();
   clutter_stage_set_title (CLUTTER_STAGE (stage), "Behaviours");
